==> tfds_nightly-4.7.0.dev202211220045-py3-none-any.whl: tensorflow_datasets/core/dataset_builders/__init__.py <==
# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Dataset builders API."""

from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllBuilderConfig
from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllDatasetBuilder
from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUBuilderConfig
from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUDatasetBuilder
from tensorflow_datasets.core.dataset_builders.huggingface_dataset_builder import HuggingfaceDatasetBuilder
from tensorflow_datasets.core.dataset_builders.tf_data_builder import TfDataBuilder
from tensorflow_datasets.core.dataset_builders.view_builder import ViewBuilder
from tensorflow_datasets.core.dataset_builders.view_builder import ViewConfig

__all__ = [
    "ConllBuilderConfig",
    "ConllDatasetBuilder",
    "ConllUBuilderConfig",
    "ConllUDatasetBuilder",
    "HuggingfaceDatasetBuilder",
    "TfDataBuilder",
]

==> tfds_nightly-4.8.1.dev202301171228-py3-none-any.whl: tensorflow_datasets/core/dataset_builders/__init__.py <==
# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Dataset builders API."""

from tensorflow_datasets.core.dataset_builders.adhoc_builder import AdhocBuilder
from tensorflow_datasets.core.dataset_builders.adhoc_builder import store_as_tfds_dataset
from tensorflow_datasets.core.dataset_builders.adhoc_builder import TfDataBuilder
from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllBuilderConfig
from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllDatasetBuilder
from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUBuilderConfig
from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUDatasetBuilder
from tensorflow_datasets.core.dataset_builders.huggingface_dataset_builder import HuggingfaceDatasetBuilder
from tensorflow_datasets.core.dataset_builders.view_builder import ViewBuilder
from tensorflow_datasets.core.dataset_builders.view_builder import ViewConfig

__all__ = [
    "AdhocBuilder",
    "ConllBuilderConfig",
    "ConllDatasetBuilder",
    "ConllUBuilderConfig",
    "ConllUDatasetBuilder",
    "HuggingfaceDatasetBuilder",
    "store_as_tfds_dataset",
    "TfDataBuilder",
    "ViewBuilder",
    "ViewConfig",
]
